@@ -62,9 +62,12 @@ impl App {
 
     /// Put the playable cards in order based of their score
     pub fn order_playables(&mut self) {
-        self.playable_cards
-            .sort_unstable_by_key(|card| *self.scores.get(card).unwrap_or(&0));
-        self.playable_cards.reverse();
+        self.playable_cards.sort_unstable_by_key(|card| {
+            (
+                *self.scores.get(card).unwrap_or(&usize::MAX),
+                *self.dues.get(card).unwrap_or(&chrono::MAX_DATETIME),
+            )
+        });
     }
 
     /// Returns an immutable copy of all the cards
@@ -137,6 +140,9 @@ impl App {
             self.playable_card_pos %= self.playable_range();
             self.card = self.playable_cards[self.playable_card_pos];
             self.flipped = false;
+            if self.playable_card_pos == 0 {
+                self.shuffle();
+            }
         }
     }
 
@@ -166,11 +172,17 @@ impl App {
 
     /// Changes the score of the current card.
     ///
-    /// A card can not have a negative score.
+    /// A card can not have a negative score. If the
+    /// `zeroize` option is true then a negative `val`
+    /// will set the score to zero.
     pub fn change_current_card_score(&mut self, val: isize) {
         let entry = self.scores.entry(self.card).or_default();
         if val > 0 {
-            *entry = entry.saturating_add(val.try_into().unwrap_or(0));
+            if self.opts.zeroize {
+                *entry = 0;
+            } else {
+                *entry = entry.saturating_add(val.try_into().unwrap_or(0));
+            }
         } else {
             *entry = entry.saturating_sub(val.try_into().unwrap_or(0));
         }
